"use strict";Object.defineProperty(exports, "__esModule", {value: true});// src/types/errors.ts
var BodyParsingError = class extends Error {
};
var PathError = class extends Error {
};

// src/utils/everyItemIsString.ts
var everyItemIsString = (array) => array.every((value) => typeof value === "string");

// src/utils/assertRequestData.ts
var requestDataTypes = [
  "all",
  "allSequential",
  "allSettled",
  "allSettledSequential",
  "request"
];
var assertRequestData = (data) => {
  if (!data || typeof data !== "object")
    throw new BodyParsingError("Could not parse body. Body must be an object.");
  if (!("type" in data) || typeof data.type !== "string" || !requestDataTypes.includes(data.type))
    throw new BodyParsingError("Could not parse body. Type must be one of the following: all, allSettled, allSequential, allSettledSequential, request.");
  if (data.type === "request") {
    if (!("path" in data) || !Array.isArray(data.path) || !everyItemIsString(data.path))
      throw new BodyParsingError("Could not parse body. Path must be an array of strings.");
    if (!("args" in data) || !Array.isArray(data.args))
      throw new BodyParsingError("Could not parse body. Args must be an array.");
  } else if (!("data" in data) || !Array.isArray(data.data) || !data.data.every(assertRequestData)) {
    throw new BodyParsingError("Could not parse body. Nested data is missing or malformed.");
  }
  return data;
};






exports.BodyParsingError = BodyParsingError; exports.PathError = PathError; exports.everyItemIsString = everyItemIsString; exports.assertRequestData = assertRequestData;
